//
//  UIViewExtension.swift
//  LongLian369
//
//  Created by 杨蒙 on 16/7/3.
//  Copyright © 2016年 北京龙链科技有限公司. All rights reserved.
//

import UIKit

// MARK: 屏幕的宽高
let JKscreenW: CGFloat = UIScreen.main.bounds.width
let JKscreenH: CGFloat = UIScreen.main.bounds.height

// MARK: 宽高的判断
/// iPhone 5
let isIPhone5 = JKscreenH == 568 ? true : false
/// iPhone 6
let isIPhone6 = JKscreenH == 667 ? true : false
/// iPhone 6P
let isIPhone6P = JKscreenH == 736 ? true : false

// MARK: 关于UIView的x，y,width,height的判断
extension UIView {
    
    /// 裁剪 view 的圆角
    func clipRectCorner(direction: UIRectCorner, cornerRadius: CGFloat) {
        let cornerSize = CGSize(width:cornerRadius, height:cornerRadius)
        let maskPath = UIBezierPath(roundedRect: bounds, byRoundingCorners: direction, cornerRadii: cornerSize)
        let maskLayer = CAShapeLayer()
        maskLayer.frame = bounds
        maskLayer.path = maskPath.cgPath
        layer.addSublayer(maskLayer)
        layer.mask = maskLayer
    }
    
    /// x
    var x: CGFloat {
        get {
            return frame.origin.x
        }
        set(newValue) {
            var tempFrame: CGRect = frame
            tempFrame.origin.x    = newValue
            frame                 = tempFrame
        }
    }
    
    /// y
    var y: CGFloat {
        get {
            return frame.origin.y
        }
        set(newValue) {
            var tempFrame: CGRect = frame
            tempFrame.origin.y    = newValue
            frame                 = tempFrame
        }
    }
    
    /// height
    var height: CGFloat {
        get {
            return frame.size.height
        }
        set(newValue) {
            var tempFrame: CGRect = frame
            tempFrame.size.height = newValue
            frame                 = tempFrame
        }
    }
    
    /// width
    var width: CGFloat {
        get {
            return frame.size.width
        }
        set(newValue) {
            var tempFrame: CGRect = frame
            tempFrame.size.width = newValue
            frame = tempFrame
        }
    }
    
    /// size
    var size: CGSize {
        get {
            return frame.size
        }
        set(newValue) {
            var tempFrame: CGRect = frame
            tempFrame.size = newValue
            frame = tempFrame
        }
    }
    
    /// centerX
    var centerX: CGFloat {
        get {
            return center.x
        }
        set(newValue) {
            var tempCenter: CGPoint = center
            tempCenter.x = newValue
            center = tempCenter
        }
    }
    
    /// centerY
    var centerY: CGFloat {
        get {
            return center.y
        }
        set(newValue) {
            var tempCenter: CGPoint = center
            tempCenter.y = newValue
            center = tempCenter;
        }
    }
    
}

// MARK: 有关颜色的判断
extension UIColor {
    
    /// RGBA的颜色设置
    static func JKColor(r:CGFloat, g:CGFloat, b:CGFloat, a:CGFloat) -> UIColor {
        return UIColor(red: r / 255.0, green: g / 255.0, blue: b / 255.0, alpha: a)
    }
    
    /// 背景灰色
    static func JKGlobalColor() -> UIColor {
        return JKColor(r: 240, g: 240, b: 240, a: 1)
    }
    
    /// 红色
    static func JKGlobalRedColor() -> UIColor {
        return JKColor(r: 245, g: 80, b: 83, a: 1.0)
    }
    
    /// 字体的灰色
    static func JKTextGayColor() -> UIColor {
        return JKColor(r: 140, g: 140, b: 140, a: 1.0)
    }
    
}

